CHANGES
=======

0.2 (2019-10-11)
------------------

- Works well with also a text including emoticon and www (Laughing expression)
- no longer use emoji package

0.1.1 (2019-10-05)
------------------

- First release
